<?php
// Include WordPress function to check if a plugin is active.
require_once ABSPATH . 'wp-admin/includes/plugin.php';

/**
 * Set the redirect to the settings page upon plugin activation.
 */
function allinwriter_activate_plugin() {
    $nonce = wp_create_nonce( 'allinwriter_plugin_redirect_nonce' );
    add_option( 'allinwriter_plugin_redirect', true );
    add_option( 'allinwriter_plugin_redirect_nonce', $nonce );
}
register_activation_hook( __FILE__, 'allinwriter_activate_plugin' );

/**
 * Redirect to the plugin settings page after activation.
 */
function allinwriter_plugin_redirect() {
    if ( get_option( 'allinwriter_plugin_redirect', false ) ) {
        delete_option( 'allinwriter_plugin_redirect' );

        if ( ! isset( $_GET['activate-multi'] ) && isset( $_GET['nonce'] ) ) {
            $nonce_from_get = sanitize_text_field( wp_unslash( $_GET['nonce'] ) );

            if ( wp_verify_nonce( $nonce_from_get, 'allinwriter_plugin_redirect_nonce' ) ) {
                delete_option( 'allinwriter_plugin_redirect_nonce' );

                wp_safe_redirect( admin_url( 'admin.php?page=allinwriter-seo-articles' ) );
                exit;
            }
        }
    }
}
add_action( 'admin_init', 'allinwriter_plugin_redirect' );

/**
 * Add admin menu pages.
 */
function allinwriter_admin_menu() {
    add_menu_page(
        __( 'AllinWriter SEO', 'seo-articles-by-allinwriter'  ),
        __( 'AllinWriter SEO', 'seo-articles-by-allinwriter'  ),
        'manage_options',
        'allinwriter-seo-articles',
        'allinwriter_settings_page',
        plugins_url( 'img/icon48.png', __FILE__ )
    );

    $api_key = get_option( 'allinwriter_api_key' );

    if ( $api_key ) {
        add_submenu_page(
            'allinwriter-seo-articles',
            __( 'AllinWriter SEO Credits', 'seo-articles-by-allinwriter'  ),
            __( 'Credits', 'seo-articles-by-allinwriter'  ),
            'manage_options',
            'allinwriter-seo-articles-credits',
            'allinwriter_credits_page'
        );

        add_submenu_page(
            'allinwriter-seo-articles',
            __( 'AllinWriter SEO FAQ', 'seo-articles-by-allinwriter'  ),
            __( 'FAQ', 'seo-articles-by-allinwriter'  ),
            'manage_options',
            'allinwriter-seo-articles-faq',
            'allinwriter_faq_page'
        );

        add_submenu_page(
            'allinwriter-seo-articles',
            __( 'AllinWriter SEO PRO', 'seo-articles-by-allinwriter'  ),
            __( 'PRO Features', 'seo-articles-by-allinwriter'  ),
            'manage_options',
            'allinwriter-seo-articles-pro',
            'allinwriter_pro_page'
        );
    }
}
add_action( 'admin_menu', 'allinwriter_admin_menu' , 20);

/**
 * Format numbers for display.
 *
 * @param int|float $num Number to format.
 * @return string Formatted number.
 */
function format_number( $num ) {
    if ( $num >= 1000000 ) {
        return number_format( $num / 1000000, 2, '.', '' ) . 'M';
    }
    if ( $num >= 1000 ) {
        return number_format( $num / 1000, 2, '.', '' ) . 'K';
    }
    return strval( $num );
}

/**
 * Check API key presence and redirect if absent.
 */
function allinwriter_check_api_key() {
    $screen  = get_current_screen();
    $api_key = get_option( 'allinwriter_api_key' );

    // Perform check on the appropriate admin pages.
    if ( ! $api_key && ( false !== strpos( $screen->id, 'allinwriter-seo-articles' ) ) ) {
        $redirect_url = admin_url( 'admin.php?page=allinwriter-seo-articles' );
        wp_safe_redirect( $redirect_url );
        exit;
    }
}

/**
 * Render the settings page.
 */
function allinwriter_settings_page() {
    $register_url = esc_url( 'https://app.allinwriter.com/register/?workspace=' . urlencode( site_url() ) );
    $api_key      = get_option( 'allinwriter_api_key' );
    $credits      = get_option( 'allinwriter_credits' );

    $main_url    = admin_url( 'admin.php?page=allinwriter-seo-articles' );
    $credits_url = admin_url( 'admin.php?page=allinwriter-seo-articles-credits' );
    $faq_url     = admin_url( 'admin.php?page=allinwriter-seo-articles-faq' );
    $pro_url     = admin_url( 'admin.php?page=allinwriter-seo-articles-pro' );

    ?>
    <div id="allinwriter-container-wp" class="wrap">
        <div class="allinwriter-header-wp">
            <h1>
                <div>
                    <a href="https://allinwriter.com" target="_blank">
                        <img src="<?php echo esc_url( plugins_url( 'img/allinwriter-logo.png', __FILE__ ) ); ?>" alt="<?php esc_attr_e( 'AllinWriter', 'seo-articles-by-allinwriter'  ); ?>" width="auto" height="48" title="AllinWriter"/>
                    </a>
                </div>
            </h1>

            <?php if ( $api_key ) : ?>
                <div id="allinwriter-credits" class="allinwriter-credits hide">
                    <div class="allinwriter-just-credits">
                        <b><?php esc_html_e( 'Credits:', 'seo-articles-by-allinwriter'  ); ?></b>
                        <span><?php echo esc_html( format_number( $credits ) ); ?></span>
                    </div>
                    <button id="allinwriter-sync-btn">
                        <svg height="24" viewBox="0 0 24 24" width="24" xmlns="http://www.w3.org/2000/svg"><path d="M6.19306266,7 L10,7 L10,9 L3,9 L3,2 L5,2 L5,5.27034886 C6.72510698,3.18251178 9.19576641,2 12,2 C17.5228475,2 22,6.4771525 22,12 C20,12 22,12 20,12 C20,7.581722 16.418278,4 12,4 C9.60637619,4 7.55353989,5.07869636 6.19306266,7 Z M17.8069373,17 L14,17 L14,15 L21,15 L21,22 L19,22 L19,18.7296511 C17.274893,20.8174882 14.8042336,22 12,22 C6.4771525,22 2,17.5228475 2,12 C2,12 4,12 4,12 C4,16.418278 7.581722,20 12,20 C14.3936238,20 16.4464601,18.9213036 17.8069373,17 Z" fill-rule="evenodd"/></svg>
                    </button>
                    <a href="https://app.allinwriter.com/plans" target="_blank" class="get-more-credits-btn"><?php esc_html_e( 'Get More', 'seo-articles-by-allinwriter'  ); ?></a>
                    <button id="allinwriter-disconnect-btn">
                        <svg style="enable-background:new 0 0 24 24;" version="1.1" viewBox="0 0 24 24" xml:space="preserve" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
                            <g id="grid_system"/><g style="fill:#f6f5f5;" id="_icons"><path d="M15.6,3.3c-1.4,0-2.6,0.5-3.6,1.5L9.8,7c-0.4,0.4-0.4,1,0,1.4s1,0.4,1.4,0l2.2-2.2c1.2-1.2,3.2-1.2,4.4,0   c0.6,0.6,0.9,1.4,0.9,2.2c0,0.8-0.3,1.6-0.9,2.2l-2.2,2.2c-0.4,0.4-0.4,1,0,1.4c0.2,0.2,0.5,0.3,0.7,0.3s0.5-0.1,0.7-0.3l2.2-2.2   c1-1,1.5-2.2,1.5-3.6c0-1.4-0.5-2.6-1.5-3.6C18.2,3.8,17,3.3,15.6,3.3z"/><path d="M8.4,11.3c0.4-0.4,0.4-1,0-1.4s-1-0.4-1.4,0L4.8,12c-1,1-1.5,2.2-1.5,3.6c0,1.4,0.5,2.6,1.5,3.6c1,1,2.2,1.5,3.6,1.5   s2.6-0.5,3.6-1.5l2.2-2.2c0.4-0.4,0.4-1,0-1.4s-1-0.4-1.4,0l-2.2,2.2c-1.2,1.2-3.2,1.2-4.4,0c-0.6-0.6-0.9-1.4-0.9-2.2   c0-0.8,0.3-1.6,0.9-2.2L8.4,11.3z"/><path d="M9.1,14.9c0.2,0.2,0.5,0.3,0.7,0.3s0.5-0.1,0.7-0.3l4.3-4.3c0.4-0.4,0.4-1,0-1.4s-1-0.4-1.4,0l-4.3,4.3   C8.7,13.8,8.7,14.5,9.1,14.9z"/></g>
                        </svg>
                    </button>
                </div>
            <?php endif; ?>
        </div>

        <div id="tabs">
            <a href="<?php echo esc_url( $pro_url ); ?>" class="tab-button <?php echo esc_attr( $api_key ? '' : 'disabled' ); ?>" id="pro-tab-button"><?php esc_html_e( 'PRO Features', 'seo-articles-by-allinwriter'  ); ?></a>
            <a href="<?php echo esc_url( $faq_url ); ?>" class="tab-button <?php echo esc_attr( $api_key ? '' : 'disabled' ); ?>" id="faq-tab-button"><?php esc_html_e( 'F.A.Q.', 'seo-articles-by-allinwriter'  ); ?></a>
            <a href="<?php echo esc_url( $credits_url ); ?>" class="tab-button <?php echo esc_attr( $api_key ? '' : 'disabled' ); ?>" id="credits-tab-button"><?php esc_html_e( 'Credits', 'seo-articles-by-allinwriter'  ); ?></a>
            <a href="<?php echo esc_url( $main_url ); ?>" class="tab-button <?php echo esc_attr( $api_key ? 'active' : '' ); ?>" id="connection-tab-button"><?php esc_html_e( 'Welcome', 'seo-articles-by-allinwriter'  ); ?></a>
        </div>

        <div class="connection-tab">
            <?php if ( ! $api_key ) : ?>
            <div id="allinwriter-connect" class="connect active">
                <h2><?php esc_html_e( 'Connection', 'seo-articles-by-allinwriter'  ); ?></h2>
                <form id="allinwriter-api-key-form">
                    <label for="allinwriter-api-key"><?php esc_html_e( 'API Key:', 'seo-articles-by-allinwriter'  ); ?></label>
                    <input type="text" id="allinwriter-api-key" name="api_key" required >
                    <button type="submit" class="button button-primary"><?php esc_html_e( 'Connect', 'seo-articles-by-allinwriter'  ); ?></button>
                    <div id="allinwriter-message"></div>
                </form>
                <p>
                    <?php
                    // translators: %1$s and %2$s wrap the clickable "register here" link, %3$s and %4$s wrap the clickable "go here" link.
                    $translated_text = esc_html__( 'If you don’t have an account, please %1$sregister here%2$s. Once registered, %3$sgo here to obtain your API key%4$s.', 'seo-articles-by-allinwriter' );

                    $translated_text = sprintf(
                        $translated_text,
                        '<a href="' . esc_url( $register_url ) . '" target="_blank">',
                        '</a>',
                        '<a href="https://app.allinwriter.com/account/api" target="_blank">',
                        '</a>'
                    );

                    echo wp_kses_post($translated_text);
                    ?>
                </p>
            </div>
            <?php else : ?>
                <div id="allinwriter-connected" class="connected">
                    <h2><?php esc_html_e( 'Tips & Tricks', 'seo-articles-by-allinwriter'  ); ?></h2>
                    <div id="allinwriter-demo" class="allinwriter-demo">
                        <iframe width="510" height="287"
                            src="https://www.youtube.com/embed/GtKKahvDHls?si=b6SW5soAgcbi"
                            title="<?php esc_attr_e( 'YouTube video player', 'seo-articles-by-allinwriter'  ); ?>"
                            frameborder="0"
                            allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share"
                            referrerpolicy="strict-origin-when-cross-origin"
                            allowfullscreen>
                        </iframe>
                    </div>
                </div>
            <?php endif; ?>
        </div>

        <div class="allinwriter-contact">
            <p><?php esc_html_e( 'Need help?', 'seo-articles-by-allinwriter'  ); ?> <a href="https://app.allinwriter.com/contact" target="_blank"><?php esc_html_e( 'Contact Us', 'seo-articles-by-allinwriter'  ); ?></a>.</p>
        </div>
    </div>
    <?php
}

/**
 * Display the credits page.
 */
function allinwriter_credits_page() {
    allinwriter_check_api_key();

    $api_key      = get_option( 'allinwriter_api_key' );
    $credits      = get_option( 'allinwriter_credits' );

    $main_url     = admin_url( 'admin.php?page=allinwriter-seo-articles' );
    $credits_url  = admin_url( 'admin.php?page=allinwriter-seo-articles-credits' );
    $faq_url      = admin_url( 'admin.php?page=allinwriter-seo-articles-faq' );
    $pro_url      = admin_url( 'admin.php?page=allinwriter-seo-articles-pro' );

    ?>
    <div id="allinwriter-container-wp" class="wrap">
        <div class="allinwriter-header-wp">
            <h1>
                <div>
                    <a href="https://allinwriter.com" target="_blank">
                        <img src="<?php echo esc_url( plugins_url( 'img/allinwriter-logo.png', __FILE__ ) ); ?>" alt="<?php esc_attr_e( 'AllinWriter', 'seo-articles-by-allinwriter'  ); ?>" width="auto" height="48" title="<?php esc_attr_e( 'AllinWriter', 'seo-articles-by-allinwriter'  ); ?>"/>
                    </a>
                </div>
            </h1>

            <?php if ( $api_key ) : ?>
                <div id="allinwriter-credits" class="allinwriter-credits hide">
                    <div class="allinwriter-just-credits">
                        <b><?php esc_html_e( 'Credits:', 'seo-articles-by-allinwriter'  ); ?></b>
                        <span><?php echo esc_html( format_number( $credits ) ); ?></span>
                    </div>
                    <button id="allinwriter-sync-btn">
                        <svg height="24" viewBox="0 0 24 24" width="24" xmlns="http://www.w3.org/2000/svg"><path d="M6.19306266,7 L10,7 L10,9 L3,9 L3,2 L5,2 L5,5.27034886 C6.72510698,3.18251178 9.19576641,2 12,2 C17.5228475,2 22,6.4771525 22,12 C20,12 22,12 20,12 C20,7.581722 16.418278,4 12,4 C9.60637619,4 7.55353989,5.07869636 6.19306266,7 Z M17.8069373,17 L14,17 L14,15 L21,15 L21,22 L19,22 L19,18.7296511 C17.274893,20.8174882 14.8042336,22 12,22 C6.4771525,22 2,17.5228475 2,12 C2,12 4,12 4,12 C4,16.418278 7.581722,20 12,20 C14.3936238,20 16.4464601,18.9213036 17.8069373,17 Z" fill-rule="evenodd"/></svg>
                    </button>
                    <a href="https://app.allinwriter.com/plans" target="_blank" class="get-more-credits-btn"><?php esc_html_e( 'Get More', 'seo-articles-by-allinwriter'  ); ?></a>
                    <button id="allinwriter-disconnect-btn">
                        <svg style="enable-background:new 0 0 24 24;" version="1.1" viewBox="0 0 24 24" xml:space="preserve" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
                            <g id="grid_system"/><g style="fill:#f6f5f5;" id="_icons"><path d="M15.6,3.3c-1.4,0-2.6,0.5-3.6,1.5L9.8,7c-0.4,0.4-0.4,1,0,1.4s1,0.4,1.4,0l2.2-2.2c1.2-1.2,3.2-1.2,4.4,0   c0.6,0.6,0.9,1.4,0.9,2.2c0,0.8-0.3,1.6-0.9,2.2l-2.2,2.2c-0.4,0.4-0.4,1,0,1.4c0.2,0.2,0.5,0.3,0.7,0.3s0.5-0.1,0.7-0.3l2.2-2.2   c1-1,1.5-2.2,1.5-3.6c0-1.4-0.5-2.6-1.5-3.6C18.2,3.8,17,3.3,15.6,3.3z"/><path d="M8.4,11.3c0.4-0.4,0.4-1,0-1.4s-1-0.4-1.4,0L4.8,12c-1,1-1.5,2.2-1.5,3.6c0,1.4,0.5,2.6,1.5,3.6c1,1,2.2,1.5,3.6,1.5   s2.6-0.5,3.6-1.5l2.2-2.2c0.4-0.4,0.4-1,0-1.4s-1-0.4-1.4,0l-2.2,2.2c-1.2,1.2-3.2,1.2-4.4,0c-0.6-0.6-0.9-1.4-0.9-2.2   c0-0.8,0.3-1.6,0.9-2.2L8.4,11.3z"/><path d="M9.1,14.9c0.2,0.2,0.5,0.3,0.7,0.3s0.5-0.1,0.7-0.3l4.3-4.3c0.4-0.4,0.4-1,0-1.4s-1-0.4-1.4,0l-4.3,4.3   C8.7,13.8,8.7,14.5,9.1,14.9z"/></g>
                        </svg>
                    </button>
                </div>
            <?php endif; ?>
        </div>

        <div id="tabs">
            <a href="<?php echo esc_url( $pro_url ); ?>" class="tab-button <?php echo esc_attr( $api_key ? '' : 'disabled' ); ?>" id="pro-tab-button"><?php esc_html_e( 'PRO Features', 'seo-articles-by-allinwriter'  ); ?></a>
            <a href="<?php echo esc_url( $faq_url ); ?>" class="tab-button <?php echo esc_attr( $api_key ? '' : 'disabled' ); ?>" id="faq-tab-button"><?php esc_html_e( 'F.A.Q.', 'seo-articles-by-allinwriter'  ); ?></a>
            <a href="<?php echo esc_url( $credits_url ); ?>" class="tab-button <?php echo esc_attr( $api_key ? 'active' : '' ); ?>" id="credits-tab-button"><?php esc_html_e( 'Credits', 'seo-articles-by-allinwriter'  ); ?></a>
            <a href="<?php echo esc_url( $main_url ); ?>" class="tab-button <?php echo esc_attr( $api_key ? '' : 'active' ); ?>" id="connection-tab-button"><?php esc_html_e( 'Welcome', 'seo-articles-by-allinwriter'  ); ?></a>
        </div>

        <div id="credits-tab" class="tab-content">
            <h2><?php esc_html_e( 'Credits', 'seo-articles-by-allinwriter'  ); ?></h2>
            <ul>
                <?php echo wp_kses_post( apply_filters( 'allinwriter_before_credits_page', '' ), 'seo-articles-by-allinwriter'  ); ?>
                <li>
                    <b><?php esc_html_e( 'Check SEO Score', 'seo-articles-by-allinwriter'  ); ?></b>
                    <ul>
                        <li><p><?php esc_html_e( '1 credit for each check.', 'seo-articles-by-allinwriter'  ); ?></p></li>
                    </ul>
                </li>
                <li>
                    <b><?php esc_html_e( 'SEO Article Light', 'seo-articles-by-allinwriter'  ); ?></b>
                    <ul>
                        <li><p><?php esc_html_e( 'This generation costs 10 credits.', 'seo-articles-by-allinwriter'  ); ?></p></li>
                        <li><p><?php esc_html_e( 'Each SEO Article Light is approximately 500-600 words and optimized for the main keyword with a content SEO score of around 50%.', 'seo-articles-by-allinwriter'  ); ?></p></li>
                        <li><p><?php esc_html_e( 'SEO Article Light increases your chance of ranking in the top on Google by 42%.', 'seo-articles-by-allinwriter'  ); ?></p></li>
                    </ul>
                </li>
                <?php echo wp_kses_post( apply_filters( 'allinwriter_after_credits_page', '' ), 'seo-articles-by-allinwriter'  ); ?>
            </ul>
        </div>
        <div class="allinwriter-contact">
            <p><?php esc_html_e( 'Need help?', 'seo-articles-by-allinwriter'  ); ?> <a href="https://app.allinwriter.com/contact" target="_blank"><?php esc_html_e( 'Contact Us', 'seo-articles-by-allinwriter'  ); ?></a>.</p>
        </div>
    </div>
    <?php
}

/**
 * Display the FAQ page.
 */
function allinwriter_faq_page() {
    allinwriter_check_api_key();

    $api_key = get_option( 'allinwriter_api_key' );
    $credits = get_option( 'allinwriter_credits' );

    $main_url    = admin_url( 'admin.php?page=allinwriter-seo-articles' );
    $credits_url = admin_url( 'admin.php?page=allinwriter-seo-articles-credits' );
    $faq_url     = admin_url( 'admin.php?page=allinwriter-seo-articles-faq' );
    $pro_url     = admin_url( 'admin.php?page=allinwriter-seo-articles-pro' );
    ?>
    <div id="allinwriter-container-wp" class="wrap">
        <div class="allinwriter-header-wp">
            <h1>
                <div>
                    <a href="https://allinwriter.com" target="_blank">
                        <img src="<?php echo esc_url( plugins_url( 'img/allinwriter-logo.png', __FILE__ ) ); ?>" alt="<?php esc_attr_e( 'AllinWriter', 'seo-articles-by-allinwriter'  ); ?>" width="auto" height="48" title="<?php esc_attr_e( 'AllinWriter', 'seo-articles-by-allinwriter'  ); ?>"/>
                    </a>
                </div>
            </h1>

            <?php if ( $api_key ) : ?>
                <div id="allinwriter-credits" class="allinwriter-credits hide">
                    <div class="allinwriter-just-credits">
                        <b><?php esc_html_e( 'Credits:', 'seo-articles-by-allinwriter'  ); ?></b>
                        <span><?php echo esc_html( format_number( $credits ) ); ?></span>
                    </div>
                    <button id="allinwriter-sync-btn">
                        <svg height="24" viewBox="0 0 24 24" width="24" xmlns="http://www.w3.org/2000/svg"><path d="M6.19306266,7 L10,7 L10,9 L3,9 L3,2 L5,2 L5,5.27034886 C6.72510698,3.18251178 9.19576641,2 12,2 C17.5228475,2 22,6.4771525 22,12 C20,12 22,12 20,12 C20,7.581722 16.418278,4 12,4 C9.60637619,4 7.55353989,5.07869636 6.19306266,7 Z M17.8069373,17 L14,17 L14,15 L21,15 L21,22 L19,22 L19,18.7296511 C17.274893,20.8174882 14.8042336,22 12,22 C6.4771525,22 2,17.5228475 2,12 C2,12 4,12 4,12 C4,16.418278 7.581722,20 12,20 C14.3936238,20 16.4464601,18.9213036 17.8069373,17 Z" fill-rule="evenodd"/></svg>
                    </button>
                    <a href="https://app.allinwriter.com/plans" target="_blank" class="get-more-credits-btn"><?php esc_html_e( 'Get More', 'seo-articles-by-allinwriter'  ); ?></a>
                    <button id="allinwriter-disconnect-btn">
                        <svg style="enable-background:new 0 0 24 24;" version="1.1" viewBox="0 0 24 24" xml:space="preserve" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
                            <g id="grid_system"/><g style="fill:#f6f5f5;" id="_icons"><path d="M15.6,3.3c-1.4,0-2.6,0.5-3.6,1.5L9.8,7c-0.4,0.4-0.4,1,0,1.4s1,0.4,1.4,0l2.2-2.2c1.2-1.2,3.2-1.2,4.4,0   c0.6,0.6,0.9,1.4,0.9,2.2c0,0.8-0.3,1.6-0.9,2.2l-2.2,2.2c-0.4,0.4-0.4,1,0,1.4c0.2,0.2,0.5,0.3,0.7,0.3s0.5-0.1,0.7-0.3l2.2-2.2   c1-1,1.5-2.2,1.5-3.6c0-1.4-0.5-2.6-1.5-3.6C18.2,3.8,17,3.3,15.6,3.3z"/><path d="M8.4,11.3c0.4-0.4,0.4-1,0-1.4s-1-0.4-1.4,0L4.8,12c-1,1-1.5,2.2-1.5,3.6c0,1.4,0.5,2.6,1.5,3.6c1,1,2.2,1.5,3.6,1.5   s2.6-0.5,3.6-1.5l2.2-2.2c0.4-0.4,0.4-1,0-1.4s-1-0.4-1.4,0l-2.2,2.2c-1.2,1.2-3.2,1.2-4.4,0c-0.6-0.6-0.9-1.4-0.9-2.2   c0-0.8,0.3-1.6,0.9-2.2L8.4,11.3z"/><path d="M9.1,14.9c0.2,0.2,0.5,0.3,0.7,0.3s0.5-0.1,0.7-0.3l4.3-4.3c0.4-0.4,0.4-1,0-1.4s-1-0.4-1.4,0l-4.3,4.3   C8.7,13.8,8.7,14.5,9.1,14.9z"/></g>
                        </svg>
                    </button>
                </div>
            <?php endif; ?>
        </div>

        <div id="tabs">
            <a href="<?php echo esc_url( $pro_url ); ?>" class="tab-button <?php echo esc_attr( $api_key ? '' : 'disabled' ); ?>" id="pro-tab-button"><?php esc_html_e( 'PRO Features', 'seo-articles-by-allinwriter'  ); ?></a>
            <a href="<?php echo esc_url( $faq_url ); ?>" class="tab-button <?php echo esc_attr( $api_key ? 'active' : '' ); ?>" id="faq-tab-button"><?php esc_html_e( 'F.A.Q.', 'seo-articles-by-allinwriter'  ); ?></a>
            <a href="<?php echo esc_url( $credits_url ); ?>" class="tab-button <?php echo esc_attr( $api_key ? '' : 'disabled' ); ?>" id="credits-tab-button"><?php esc_html_e( 'Credits', 'seo-articles-by-allinwriter'  ); ?></a>
            <a href="<?php echo esc_url( $main_url ); ?>" class="tab-button <?php echo esc_attr( $api_key ? '' : 'active' ); ?>" id="connection-tab-button"><?php esc_html_e( 'Welcome', 'seo-articles-by-allinwriter'  ); ?></a>
        </div>

        <div id="faq-tab" class="tab-content">
            <h2><?php esc_html_e( 'Frequently Asked Questions', 'seo-articles-by-allinwriter'  ); ?></h2>
            <ul>
                <?php echo wp_kses_post( apply_filters( 'allinwriter_before_faq_page', '' ) ); ?>
                <li>
                    <b><?php esc_html_e( 'What can I do for free?', 'seo-articles-by-allinwriter'  ); ?></b>
                    <ul>
                        <li>
                            <p><?php esc_html_e( 'Each month, your account will have 20 free credits. This is sufficient to create two SEO articles around 500-600 words, optimized for the primary target keyword and achieving a content score of approximately 50%.', 'seo-articles-by-allinwriter'  ); ?></p>
                        </li>
                    </ul>
                </li>
                <li>
                    <b><?php esc_html_e( 'Why is my article content not updating?', 'seo-articles-by-allinwriter'  ); ?></b>
                    <ul>
                        <li>
                            <p>
                                <?php esc_html_e( 'If the content is generated within our platform but not published in your article, go to', 'seo-articles-by-allinwriter'  ); ?>
                                <a href="<?php echo esc_url( admin_url( 'options-permalink.php' ) ); ?>">
                                    <?php esc_html_e( 'Settings -> Permalinks', 'seo-articles-by-allinwriter'  ); ?>
                                </a>
                                <?php esc_html_e( 'and click the `Save Changes` button to update the permalinks. After doing this, your generated/optimized article will always update.', 'seo-articles-by-allinwriter'  ); ?>
                            </p>
                        </li>
                    </ul>
                </li>
                <li>
                    <b><?php esc_html_e( 'What is the SEO Articles by AllinWriter plugin?', 'seo-articles-by-allinwriter'  ); ?></b>
                    <ul>
                        <li>
                            <p><?php esc_html_e( 'It is a WordPress plugin designed to help you generate SEO optimized articles to improve your website\'s ranking on search engines like Google.', 'seo-articles-by-allinwriter'  ); ?></p>
                        </li>
                    </ul>
                </li>
                <li>
                    <b><?php esc_html_e( 'How do I connect the plugin to my AllinWriter account?', 'seo-articles-by-allinwriter'  ); ?></b>
                    <ul>
                        <li>
                            <p><?php esc_html_e( 'Simply enter your AllinWriter API Key in the connection tab of the settings page. If you don’t have an API key, you must register on AllinWriter to obtain one.', 'seo-articles-by-allinwriter'  ); ?></p>
                        </li>
                    </ul>
                </li>
                <li>
                    <b><?php esc_html_e( 'Why do I need credits?', 'seo-articles-by-allinwriter'  ); ?></b>
                    <ul>
                        <li>
                            <p><?php esc_html_e( 'Credits are required to generate articles. Each type of article has a specific credit cost, and this ensures you only use what you need.', 'seo-articles-by-allinwriter'  ); ?></p>
                        </li>
                    </ul>
                </li>
                <li>
                    <b><?php esc_html_e( 'How can I acquire more credits?', 'seo-articles-by-allinwriter'  ); ?></b>
                    <ul>
                        <li>
                            <p><?php esc_html_e( 'You can purchase additional credits from your AllinWriter account page. Navigate to the Plans section to choose a suitable package.', 'seo-articles-by-allinwriter'  ); ?></p>
                        </li>
                    </ul>
                </li>
                <li>
                    <b><?php esc_html_e( 'Will using this plugin improve my Google rankings immediately?', 'seo-articles-by-allinwriter'  ); ?></b>
                    <ul>
                        <li>
                            <p><?php esc_html_e( 'Improving Google rankings takes time and depends on many factors, but using well-optimized content is a significant step towards better visibility.', 'seo-articles-by-allinwriter'  ); ?></p>
                        </li>
                    </ul>
                </li>
                <li>
                    <b><?php esc_html_e( 'Why haven\'t my credits updated?', 'seo-articles-by-allinwriter'  ); ?></b>
                    <ul>
                        <li>
                            <p><?php esc_html_e( 'Credits are updated after each operation, but in certain scenarios where they have not been updated, please press the "sync" button in the menu.', 'seo-articles-by-allinwriter'  ); ?></p>
                        </li>
                    </ul>
                </li>
                <li>
                    <b><?php esc_html_e( 'What does the Check Score feature do?', 'seo-articles-by-allinwriter'  ); ?></b>
                    <ul>
                        <li>
                            <p><?php esc_html_e( 'The Check Score feature evaluates the optimization score of the article after any edits to the text, content, structure, or secondary keywords.', 'seo-articles-by-allinwriter'  ); ?></p>
                        </li>
                    </ul>
                </li>
                <?php echo wp_kses_post( apply_filters( 'allinwriter_after_faq_page', '' ) ); ?>
            </ul>
        </div>

        <div class="allinwriter-contact">
            <p><?php esc_html_e( 'Need help?', 'seo-articles-by-allinwriter'  ); ?> <a href="https://app.allinwriter.com/contact" target="_blank"><?php esc_html_e( 'Contact Us', 'seo-articles-by-allinwriter'  ); ?></a>.</p>
        </div>
    </div>
    <?php
}

/**
 * Display the PRO features page.
 */
function allinwriter_pro_page() {
    allinwriter_check_api_key();

    $api_key     = get_option( 'allinwriter_api_key' );
    $credits     = get_option( 'allinwriter_credits' );

    $main_url    = admin_url( 'admin.php?page=allinwriter-seo-articles' );
    $credits_url = admin_url( 'admin.php?page=allinwriter-seo-articles-credits' );
    $faq_url     = admin_url( 'admin.php?page=allinwriter-seo-articles-faq' );
    $pro_url     = admin_url( 'admin.php?page=allinwriter-seo-articles-pro' );

    ?>
    <div id="allinwriter-container-wp" class="wrap">
        <div class="allinwriter-header-wp">
            <h1>
                <div>
                    <a href="https://allinwriter.com" target="_blank">
                        <img src="<?php echo esc_url( plugins_url( 'img/allinwriter-logo.png', __FILE__ ) ); ?>" alt="<?php esc_attr_e( 'AllinWriter', 'seo-articles-by-allinwriter'  ); ?>" width="auto" height="48" title="<?php esc_attr_e( 'AllinWriter', 'seo-articles-by-allinwriter'  ); ?>"/>
                    </a>
                </div>
            </h1>

            <?php if ( $api_key ) : ?>
                <div id="allinwriter-credits" class="allinwriter-credits hide">
                    <div class="allinwriter-just-credits">
                        <b><?php esc_html_e( 'Credits:', 'seo-articles-by-allinwriter'  ); ?></b>
                        <span><?php echo esc_html( format_number( $credits ) ); ?></span>
                    </div>
                    <button id="allinwriter-sync-btn">
                        <svg height="24" viewBox="0 0 24 24" width="24" xmlns="http://www.w3.org/2000/svg"><path d="M6.19306266,7 L10,7 L10,9 L3,9 L3,2 L5,2 L5,5.27034886 C6.72510698,3.18251178 9.19576641,2 12,2 C17.5228475,2 22,6.4771525 22,12 C20,12 22,12 20,12 C20,7.581722 16.418278,4 12,4 C9.60637619,4 7.55353989,5.07869636 6.19306266,7 Z M17.8069373,17 L14,17 L14,15 L21,15 L21,22 L19,22 L19,18.7296511 C17.274893,20.8174882 14.8042336,22 12,22 C6.4771525,22 2,17.5228475 2,12 C2,12 4,12 4,12 C4,16.418278 7.581722,20 12,20 C14.3936238,20 16.4464601,18.9213036 17.8069373,17 Z" fill-rule="evenodd"/></svg>
                    </button>
                    <a href="https://app.allinwriter.com/plans" target="_blank" class="get-more-credits-btn"><?php esc_html_e( 'Get More', 'seo-articles-by-allinwriter'  ); ?></a>
                    <button id="allinwriter-disconnect-btn">
                        <svg style="enable-background:new 0 0 24 24;" version="1.1" viewBox="0 0 24 24" xml:space="preserve" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink">
                            <g id="grid_system"/><g style="fill:#f6f5f5;" id="_icons"><path d="M15.6,3.3c-1.4,0-2.6,0.5-3.6,1.5L9.8,7c-0.4,0.4-0.4,1,0,1.4s1,0.4,1.4,0l2.2-2.2c1.2-1.2,3.2-1.2,4.4,0   c0.6,0.6,0.9,1.4,0.9,2.2c0,0.8-0.3,1.6-0.9,2.2l-2.2,2.2c-0.4,0.4-0.4,1,0,1.4c0.2,0.2,0.5,0.3,0.7,0.3s0.5-0.1,0.7-0.3l2.2-2.2   c1-1,1.5-2.2,1.5-3.6c0-1.4-0.5-2.6-1.5-3.6C18.2,3.8,17,3.3,15.6,3.3z"/><path d="M8.4,11.3c0.4-0.4,0.4-1,0-1.4s-1-0.4-1.4,0L4.8,12c-1,1-1.5,2.2-1.5,3.6c0,1.4,0.5,2.6,1.5,3.6c1,1,2.2,1.5,3.6,1.5   s2.6-0.5,3.6-1.5l2.2-2.2c0.4-0.4,0.4-1,0-1.4s-1-0.4-1.4,0l-2.2,2.2c-1.2,1.2-3.2,1.2-4.4,0c-0.6-0.6-0.9-1.4-0.9-2.2   c0-0.8,0.3-1.6,0.9-2.2L8.4,11.3z"/><path d="M9.1,14.9c0.2,0.2,0.5,0.3,0.7,0.3s0.5-0.1,0.7-0.3l4.3-4.3c0.4-0.4,0.4-1,0-1.4s-1-0.4-1.4,0l-4.3,4.3   C8.7,13.8,8.7,14.5,9.1,14.9z"/></g>
                        </svg>
                    </button>
                </div>
            <?php endif; ?>
        </div>

        <div id="tabs">
            <a href="<?php echo esc_url( $pro_url ); ?>" class="tab-button <?php echo esc_attr( $api_key ? 'active' : '' ); ?>" id="pro-tab-button"><?php esc_html_e( 'PRO Features', 'seo-articles-by-allinwriter'  ); ?></a>
            <a href="<?php echo esc_url( $faq_url ); ?>" class="tab-button <?php echo esc_attr( $api_key ? '' : '' ); ?>" id="faq-tab-button"><?php esc_html_e( 'F.A.Q.', 'seo-articles-by-allinwriter'  ); ?></a>
            <a href="<?php echo esc_url( $credits_url ); ?>" class="tab-button <?php echo esc_attr( $api_key ? '' : '' ); ?>" id="credits-tab-button"><?php esc_html_e( 'Credits', 'seo-articles-by-allinwriter'  ); ?></a>
            <a href="<?php echo esc_url( $main_url ); ?>" class="tab-button <?php echo esc_attr( $api_key ? '' : 'active' ); ?>" id="connection-tab-button"><?php esc_html_e( 'Welcome', 'seo-articles-by-allinwriter'  ); ?></a>
        </div>

        <div id="pro-tab" class="tab-content">
            <h2><?php esc_html_e( 'PRO Features', 'seo-articles-by-allinwriter'  ); ?></h2>
            <ul>
                <li>
                    <b><?php esc_html_e( 'SEO Article Pro', 'seo-articles-by-allinwriter'  ); ?></b>
                    <ul>
                        <li><p><?php esc_html_e( 'SEO Article Pro is approximately 3000 words, up-to-date, and provides relevant content with automated keyword research to optimize for secondary keywords, achieving a content SEO score of around 90%.', 'seo-articles-by-allinwriter'  ); ?></p></li>
                        <li><p><?php esc_html_e( 'SEO Article Pro increases your chance of ranking at the top on Google by over 500%.', 'seo-articles-by-allinwriter'  ); ?></p></li>
                    </ul>
                </li>
                <li><b><?php esc_html_e( 'SEO Article Optimizer', 'seo-articles-by-allinwriter'  ); ?></b> - <?php esc_html_e( 'optimizes the SEO of articles that have already been written or published.', 'seo-articles-by-allinwriter'  ); ?></li>
                <li><a href="https://app.allinwriter.com/audits" target="_blank"><?php esc_html_e( 'Audit', 'seo-articles-by-allinwriter'  ); ?></a> <?php esc_html_e( '- If you want a complete audit of your site to assess its SEO performance on Google for the most searched keywords relevant to your site.', 'seo-articles-by-allinwriter'  ); ?></li>
                <li><a href="https://app.allinwriter.com/research" target="_blank"><?php esc_html_e( 'Keyword Research', 'seo-articles-by-allinwriter'  ); ?></a> <?php esc_html_e( '- If you need to perform research to discover keywords with high search volumes on Google and low competition.', 'seo-articles-by-allinwriter'  ); ?></li>
                <li><a href="https://app.allinwriter.com/monitor" target="_blank"><?php esc_html_e( 'Monitor', 'seo-articles-by-allinwriter'  ); ?></a> <?php esc_html_e( '- Constant monitoring of the evolution of your SEO articles on Google.', 'seo-articles-by-allinwriter'  ); ?></li>
                <li><a href="https://app.allinwriter.com/publisher" target="_blank"><?php esc_html_e( 'PressLinks', 'seo-articles-by-allinwriter'  ); ?></a> <?php esc_html_e( '- Publishing advertorials on tens of thousands of sites to build backlinks and for promotion.', 'seo-articles-by-allinwriter'  ); ?></li>
                <li><a href="https://app.allinwriter.com/awrobots" target="_blank"><?php esc_html_e( 'AI Marketer', 'seo-articles-by-allinwriter'  ); ?></a> <?php esc_html_e( '- takes care of keyword research, generates and publishes SEO articles on your site automatically according to your desired schedule.', 'seo-articles-by-allinwriter'  ); ?></li>
                <li><a href="https://app.allinwriter.com/image-editor" target="_blank"><?php esc_html_e( 'AI Designer', 'seo-articles-by-allinwriter'  ); ?></a> <?php esc_html_e( '- you can instantly generate amazing photos for your website.', 'seo-articles-by-allinwriter'  ); ?></li>
                <li><a href="https://app.allinwriter.com/chrome-extension" target="_blank"><?php esc_html_e( 'AI Assistant', 'seo-articles-by-allinwriter'  ); ?></a> <?php esc_html_e( '- is a browser extension that offers services in content creation, text-to-speech, image, and SEO articles.', 'seo-articles-by-allinwriter'  ); ?></li>
            </ul>
        </div>
        <div class="allinwriter-contact">
            <p><?php esc_html_e( 'Need help?', 'seo-articles-by-allinwriter'  ); ?> <a href="https://app.allinwriter.com/contact" target="_blank"><?php esc_html_e( 'Contact Us', 'seo-articles-by-allinwriter'  ); ?></a>.</p>
        </div>
    </div>
    <?php
}

/**
 * Include enqueue scripts and styles.
 */
function allinwriter_enqueue_scripts( $hook ) {
    wp_enqueue_style( 'allinwriter-all-style', plugins_url( 'css/all.css', __FILE__ ), array(), SEO_BY_ALLINWRITER_VERSION );
    
    $screen = get_current_screen();
    // Enqueue scripts for the plugin settings page
    if ( 'toplevel_page_allinwriter-seo-articles' === $hook || 
        'allinwriter-seo_page_allinwriter-seo-articles-credits' === $hook || 
        'allinwriter-seo_page_allinwriter-seo-articles-faq' === $hook || 
        'allinwriter-seo_page_allinwriter-seo-articles-pro' === $hook
    ) {
        allinwriter_enqueue_dependents();
        wp_enqueue_script( 'allinwriter-main', plugins_url( 'js/allinwriter.js', __FILE__ ), array( 'jquery', 'toastr' ), SEO_BY_ALLINWRITER_VERSION, true );
        wp_enqueue_style( 'allinwriter-style', plugins_url( 'css/allinwriter.css', __FILE__ ), array(), SEO_BY_ALLINWRITER_VERSION );
    }

    // Enqueue for Gutenberg
    if ( $screen && $screen->is_block_editor ) {
        allinwriter_enqueue_dependents();
        wp_enqueue_script( 'allinwriter-main', plugins_url( 'js/allinwriter.js', __FILE__ ), array( 'jquery', 'toastr' ), SEO_BY_ALLINWRITER_VERSION, true );
        wp_enqueue_style( 'allinwriter-style', plugins_url( 'css/allinwriter.css', __FILE__ ), array(), SEO_BY_ALLINWRITER_VERSION );
    }

    // General editor panel check for Classic
    if ( in_array( $hook, array( 'post-new.php', 'post.php' ), true ) ) {
        allinwriter_enqueue_dependents();
        wp_enqueue_script( 'allinwriter-main', plugins_url( 'js/allinwriter.js', __FILE__ ), array( 'jquery', 'toastr' ), SEO_BY_ALLINWRITER_VERSION, true );
        wp_enqueue_style( 'allinwriter-style', plugins_url( 'css/allinwriter.css', __FILE__ ), array(), SEO_BY_ALLINWRITER_VERSION );
    }
}
add_action( 'admin_enqueue_scripts', 'allinwriter_enqueue_scripts' );


/**
 * Load scripts and styles for Elementor.
 */
function allinwriter_custom_enqueue_scripts() {
    // Enqueue scripts and styles
    wp_enqueue_script( 'allinwriter-main', plugins_url( 'js/allinwriter.js', __FILE__ ), array( 'jquery', 'toastr' ), SEO_BY_ALLINWRITER_VERSION, true );
    wp_enqueue_style( 'allinwriter-style', plugins_url( 'css/allinwriter.css', __FILE__ ), array(), SEO_BY_ALLINWRITER_VERSION );
}
add_action( 'elementor/editor/after_enqueue_scripts', 'allinwriter_custom_enqueue_scripts' );

/**
 * Localize the script for editor context.
 */
function allinwriter_localize_script() {
    global $post;
    
    $post_id = $post ? $post->ID : 0;
    $score = get_post_meta( $post_id, '_allinwriter_seo_score', true );

    $fields = apply_filters( 'allinwriter_custom_fields', '' );

    wp_localize_script( 'allinwriter-main', 'allinwriter_vars', array(
        'ajax_url' => admin_url( 'admin-ajax.php' ),
        'admin_url' => admin_url(),
        'nonce' => wp_create_nonce( 'allinwriter_nonce' ),
        'user_plan' => get_option( 'allinwriter_user_plan', 'free' ),
        'connected' => get_option( 'allinwriter_api_key' ) ? true : false,
        'score' => $score ? intval( $score ) : -1,
        'allinwriter_post_id' => $post_id,
        'custom_fields' => $fields
    ) );
}
add_action( 'admin_enqueue_scripts', 'allinwriter_localize_script');
add_action( 'elementor/editor/after_enqueue_scripts', 'allinwriter_localize_script' );

/**
 * Enqueue essential scripts globally.
 */
function allinwriter_enqueue_dependents() {
    wp_enqueue_script( 'jquery' );
    wp_enqueue_script( 'toastr', plugins_url( 'libs/js/toastr.min.js', __FILE__ ), array( 'jquery' ), SEO_BY_ALLINWRITER_VERSION, true );
    wp_enqueue_script( 'tooltipster', plugins_url( 'libs/js/tooltipster.min.js', __FILE__ ), array( 'jquery' ), SEO_BY_ALLINWRITER_VERSION, true );
    wp_enqueue_style( 'toastr-css', plugins_url( 'libs/css/toastr.min.css', __FILE__ ), array(), SEO_BY_ALLINWRITER_VERSION );
    wp_enqueue_style( 'tooltipster-css', plugins_url( 'libs/css/tooltipster.min.css', __FILE__ ), array(), SEO_BY_ALLINWRITER_VERSION );
    wp_enqueue_style( 'tooltipster-borderless-css', plugins_url( 'libs/css/tooltipster.borderless.min.css', __FILE__ ), array(), SEO_BY_ALLINWRITER_VERSION );
    wp_enqueue_style( 'tooltipster-side-css', plugins_url( 'libs/css/tooltipster.side.min.css', __FILE__ ), array(), SEO_BY_ALLINWRITER_VERSION );
}
add_action( 'elementor/editor/before_enqueue_scripts', 'allinwriter_enqueue_dependents' );

/**
 * Validate API Key via AJAX.
 */
function allinwriter_validate_api_key() {
    check_ajax_referer( 'allinwriter_nonce', 'security' );
    
    $api_key = isset( $_POST['api_key'] ) ? sanitize_text_field( wp_unslash( $_POST['api_key'] ) ) : '';
    
    $response = wp_remote_post( 'https://app.allinwriter.com/api/v1/connect/api', array(
        'headers' => array(
            'Content-Type' => 'application/json',
            'Authorization' => 'Bearer ' . $api_key,
        ),
        'body' => wp_json_encode(array('website' => site_url(), 'source' => 'wp', 'type' => 'connect')),
    ));

    $body = wp_remote_retrieve_body( $response );
    $data = json_decode( $body, true );

    if ( isset( $data['status'] ) && 'success' === $data['status'] ) {
        update_option( 'allinwriter_api_key', $api_key );
        update_option( 'allinwriter_credits', $data['remained_credits'] );
        update_option( 'allinwriter_user_plan', $data['plan'] );  
        wp_send_json_success( array( 'message' => __( 'API Key validated and saved successfully.', 'seo-articles-by-allinwriter'  ) ) );
    } else {
        wp_send_json_error( array( 'message' => $data['message'] ?? __( 'Failed to validate the API key.', 'seo-articles-by-allinwriter'  ) ) );
    }
}
add_action( 'wp_ajax_allinwriter_validate_api_key', 'allinwriter_validate_api_key' );

/**
 * Handle user disconnect via AJAX.
 */
function allinwriter_disconnect_user() {
    check_ajax_referer( 'allinwriter_nonce', 'security' );

    $api_key = isset( $_POST['api_key'] ) ? sanitize_text_field( wp_unslash( $_POST['api_key'] ) ) : '';
    
    $response = wp_remote_post( 'https://app.allinwriter.com/api/v1/connect/api', array(
        'headers' => array(
            'Content-Type' => 'application/json',
            'Authorization' => 'Bearer ' . $api_key,
        ),
        'body' => wp_json_encode(array('website' => site_url(), 'source' => 'wp', 'type' => 'disconnect')),
    ));

    $body = wp_remote_retrieve_body( $response );
    $data = json_decode( $body, true );

    delete_option( 'allinwriter_api_key' );
    delete_option( 'allinwriter_credits' );
    delete_option( 'allinwriter_user_plan' );

    wp_send_json_success( array( 'message' => __( 'Disconnected successfully.', 'seo-articles-by-allinwriter'  ), 'data' => $data ) );
}
add_action( 'wp_ajax_allinwriter_disconnect_user', 'allinwriter_disconnect_user' );

/**
 * Add button to the classic editor.
 */
function allinwriter_add_classic_button() {
    ?>
    <div id="allinwriter-main-menu-seo-article-container">
        <div class="allinwriter-seo-article-container-full">
            <div class="allinwriter-speedometer-container">
                <div class="allinwriter-speedometer">
                    <div id="allinwriter-indicator" class="allinwriter-speedometer-indicator" style="--allinwriter-score:0"></div>
                    <span id="allinwriter-score" class="allinwriter-score">N/A</span>
                    <div class="allinwriter-check-score">
                        <svg style="enable-background:new 0 0 24 24;width: 20px;" version="1.1" viewBox="0 0 24 24" xml:space="preserve" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><style type="text/css">
                            .st0{display:none;}
                            .st1{display:inline;}
                            .st2{opacity:0.2;fill:none;stroke:#000000;stroke-width:5.000000e-02;stroke-miterlimit:10;}
                            </style><g class="st0" id="grid_system"></g><g id="_icons" style="fill: #c7b5e9;"><g><path d="M19.9,11c-0.6,0-1,0.4-1,1c0,3.9-3.1,7-7,7c-0.2,0-0.5,0-0.7,0c-0.2,0-0.3,0-0.5-0.1c-0.2,0-0.3-0.1-0.5-0.1    c-0.1,0-0.2-0.1-0.3-0.1c-0.5-0.2-1-0.4-1.5-0.6c0,0,0,0,0,0C8.2,18,8,17.8,7.8,17.7c-0.1-0.1-0.2-0.1-0.3-0.2    c-0.1-0.1-0.2-0.2-0.3-0.2C7.2,17.2,7,17,6.9,16.9c-0.1-0.1-0.1-0.1-0.2-0.2l1.8-0.3c0.5-0.1,0.9-0.6,0.8-1.2    c-0.1-0.5-0.6-0.9-1.2-0.8L4.8,15c0,0,0,0,0,0L4,15.2c-0.3,0-0.5,0.2-0.6,0.4c-0.2,0.2-0.2,0.5-0.2,0.7l0.8,4.2    c0.1,0.5,0.5,0.8,1,0.8c0.1,0,0.1,0,0.2,0c0.5-0.1,0.9-0.6,0.8-1.2l-0.3-1.7c0,0,0,0,0,0c0.3,0.2,0.5,0.5,0.7,0.6c0,0,0,0,0.1,0    c0.1,0.1,0.2,0.1,0.3,0.2c0.2,0.2,0.5,0.3,0.7,0.5c0,0,0,0,0,0C7.7,20,8,20.1,8.3,20.3l0.1,0c0.1,0.1,0.3,0.1,0.5,0.2    c0.4,0.1,0.8,0.2,1.1,0.3c0.2,0,0.4,0.1,0.6,0.1c0,0,0.1,0,0.1,0c0.1,0,0.3,0,0.4,0c0.2,0,0.5,0,0.7,0c5,0,9-4,9-9    C20.9,11.4,20.4,11,19.9,11z"></path><path d="M4,13c0.6,0,1-0.4,1-1c0-3.9,3.1-7,7-7c0.2,0,0.5,0,0.7,0c0.2,0,0.3,0,0.5,0.1c0.2,0,0.3,0.1,0.5,0.1    c0.1,0,0.2,0.1,0.3,0.1c0.7,0.2,1.4,0.6,2,1c0.1,0.1,0.2,0.1,0.3,0.2c0.1,0.1,0.2,0.2,0.3,0.2C16.7,6.8,16.8,7,17,7.1    c0.1,0.1,0.1,0.1,0.2,0.2l-1.8,0.3c-0.5,0.1-0.9,0.6-0.8,1.2c0.1,0.5,0.5,0.8,1,0.8c0.1,0,0.1,0,0.2,0l4.2-0.8    c0.3,0,0.5-0.2,0.6-0.4s0.2-0.5,0.2-0.7L20,3.5c-0.1-0.5-0.6-0.9-1.2-0.8c-0.5,0.1-0.9,0.6-0.8,1.2l0.3,1.7c0,0,0,0,0,0    c-0.2-0.2-0.5-0.4-0.7-0.6c0,0,0,0-0.1,0c-0.1-0.1-0.2-0.1-0.3-0.2c-0.2-0.2-0.4-0.3-0.7-0.5c0,0,0,0-0.1,0    c-0.3-0.2-0.6-0.3-0.9-0.5l-0.1,0c-0.1-0.1-0.3-0.1-0.5-0.2c-0.4-0.1-0.8-0.2-1.1-0.3c-0.2,0-0.4-0.1-0.6-0.1c0,0-0.1,0-0.1,0    c-0.1,0-0.3,0-0.4,0c-0.2,0-0.5,0-0.7,0c-5,0-9,4-9,9C3,12.6,3.4,13,4,13z"></path><path d="M12,9c-1.7,0-3,1.3-3,3s1.3,3,3,3s3-1.3,3-3S13.7,9,12,9z M12,13c-0.6,0-1-0.4-1-1s0.4-1,1-1s1,0.4,1,1S12.6,13,12,13z"></path></g></g>
                        </svg>
                    </div>
                </div>
            </div>
            <div id="allinwriter-move-button-wp"></div>
            <button id="allinwriter-btn" class="allinwriter-seo-articles-btn allinwriter-button">
                <img src="<?php echo esc_url( plugins_url( 'img/icon48.png', __FILE__ ) ); ?>" alt="SEO Article"/>
                SEO Article
            </button>
        </div>
    </div>
    <?php
}
add_action( 'edit_form_after_title', 'allinwriter_add_classic_button' );

/**
 * Add button to Gutenberg editor.
 */
function allinwriter_add_gutenberg_button() {
    $screen = get_current_screen();
    if ( $screen->is_block_editor ) {
        add_action( 'admin_footer', function() { ?>

        <div id="allinwriter-main-menu-seo-article-container">
            <div class="allinwriter-seo-article-container-full">
                <div class="allinwriter-speedometer-container">
                    <div class="allinwriter-speedometer">
                        <div id="allinwriter-indicator" class="allinwriter-speedometer-indicator" style="--allinwriter-score:0"></div>
                        <span id="allinwriter-score" class="allinwriter-score">N/A</span>
                        <div class="allinwriter-check-score">
                            <svg style="enable-background:new 0 0 24 24;width: 20px;" version="1.1" viewBox="0 0 24 24" xml:space="preserve" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><style type="text/css">
                                .st0{display:none;}
                                .st1{display:inline;}
                                .st2{opacity:0.2;fill:none;stroke:#000000;stroke-width:5.000000e-02;stroke-miterlimit:10;}
                                </style><g class="st0" id="grid_system"></g><g id="_icons" style="fill: #c7b5e9;"><g><path d="M19.9,11c-0.6,0-1,0.4-1,1c0,3.9-3.1,7-7,7c-0.2,0-0.5,0-0.7,0c-0.2,0-0.3,0-0.5-0.1c-0.2,0-0.3-0.1-0.5-0.1    c-0.1,0-0.2-0.1-0.3-0.1c-0.5-0.2-1-0.4-1.5-0.6c0,0,0,0,0,0C8.2,18,8,17.8,7.8,17.7c-0.1-0.1-0.2-0.1-0.3-0.2    c-0.1-0.1-0.2-0.2-0.3-0.2C7.2,17.2,7,17,6.9,16.9c-0.1-0.1-0.1-0.1-0.2-0.2l1.8-0.3c0.5-0.1,0.9-0.6,0.8-1.2    c-0.1-0.5-0.6-0.9-1.2-0.8L4.8,15c0,0,0,0,0,0L4,15.2c-0.3,0-0.5,0.2-0.6,0.4c-0.2,0.2-0.2,0.5-0.2,0.7l0.8,4.2    c0.1,0.5,0.5,0.8,1,0.8c0.1,0,0.1,0,0.2,0c0.5-0.1,0.9-0.6,0.8-1.2l-0.3-1.7c0,0,0,0,0,0c0.3,0.2,0.5,0.5,0.7,0.6c0,0,0,0,0.1,0    c0.1,0.1,0.2,0.1,0.3,0.2c0.2,0.2,0.5,0.3,0.7,0.5c0,0,0,0,0,0C7.7,20,8,20.1,8.3,20.3l0.1,0c0.1,0.1,0.3,0.1,0.5,0.2    c0.4,0.1,0.8,0.2,1.1,0.3c0.2,0,0.4,0.1,0.6,0.1c0,0,0.1,0,0.1,0c0.1,0,0.3,0,0.4,0c0.2,0,0.5,0,0.7,0c5,0,9-4,9-9    C20.9,11.4,20.4,11,19.9,11z"></path><path d="M4,13c0.6,0,1-0.4,1-1c0-3.9,3.1-7,7-7c0.2,0,0.5,0,0.7,0c0.2,0,0.3,0,0.5,0.1c0.2,0,0.3,0.1,0.5,0.1    c0.1,0,0.2,0.1,0.3,0.1c0.7,0.2,1.4,0.6,2,1c0.1,0.1,0.2,0.1,0.3,0.2c0.1,0.1,0.2,0.2,0.3,0.2C16.7,6.8,16.8,7,17,7.1    c0.1,0.1,0.1,0.1,0.2,0.2l-1.8,0.3c-0.5,0.1-0.9,0.6-0.8,1.2c0.1,0.5,0.5,0.8,1,0.8c0.1,0,0.1,0,0.2,0l4.2-0.8    c0.3,0,0.5-0.2,0.6-0.4s0.2-0.5,0.2-0.7L20,3.5c-0.1-0.5-0.6-0.9-1.2-0.8c-0.5,0.1-0.9,0.6-0.8,1.2l0.3,1.7c0,0,0,0,0,0    c-0.2-0.2-0.5-0.4-0.7-0.6c0,0,0,0-0.1,0c-0.1-0.1-0.2-0.1-0.3-0.2c-0.2-0.2-0.4-0.3-0.7-0.5c0,0,0,0-0.1,0    c-0.3-0.2-0.6-0.3-0.9-0.5l-0.1,0c-0.1-0.1-0.3-0.1-0.5-0.2c-0.4-0.1-0.8-0.2-1.1-0.3c-0.2,0-0.4-0.1-0.6-0.1c0,0-0.1,0-0.1,0    c-0.1,0-0.3,0-0.4,0c-0.2,0-0.5,0-0.7,0c-5,0-9,4-9,9C3,12.6,3.4,13,4,13z"></path><path d="M12,9c-1.7,0-3,1.3-3,3s1.3,3,3,3s3-1.3,3-3S13.7,9,12,9z M12,13c-0.6,0-1-0.4-1-1s0.4-1,1-1s1,0.4,1,1S12.6,13,12,13z"></path></g></g>
                            </svg>
                        </div>
                    </div>
                </div>
                <div id="allinwriter-move-button-wp"></div>
                <button id="allinwriter-btn" class="allinwriter-seo-articles-btn allinwriter-button">
                    <img src="<?php echo esc_url( plugins_url( 'img/icon48.png', __FILE__ ) ); ?>" alt="SEO Article"/>
                    SEO Article
                </button>
            </div>
        </div>
        <?php } );
    }
}
add_action( 'current_screen', 'allinwriter_add_gutenberg_button' );

/**
 * Add button in Elementor.
 */
add_action( 'elementor/editor/before_enqueue_scripts', function() {
    if ( Elementor\Plugin::$instance->editor->is_edit_mode() ) {
        add_action( 'elementor/editor/footer', function() { ?>

        <div id="allinwriter-main-menu-seo-article-container">
            <div class="allinwriter-seo-article-container-full">
                <div class="allinwriter-speedometer-container">
                    <div class="allinwriter-speedometer">
                        <div id="allinwriter-indicator" class="allinwriter-speedometer-indicator" style="--allinwriter-score:0"></div>
                        <span id="allinwriter-score" class="allinwriter-score">N/A</span>
                        <div class="allinwriter-check-score">
                            <svg style="enable-background:new 0 0 24 24;width: 20px;" version="1.1" viewBox="0 0 24 24" xml:space="preserve" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><style type="text/css">
                                .st0{display:none;}
                                .st1{display:inline;}
                                .st2{opacity:0.2;fill:none;stroke:#000000;stroke-width:5.000000e-02;stroke-miterlimit:10;}
                                </style><g class="st0" id="grid_system"></g><g id="_icons" style="fill: #c7b5e9;"><g><path d="M19.9,11c-0.6,0-1,0.4-1,1c0,3.9-3.1,7-7,7c-0.2,0-0.5,0-0.7,0c-0.2,0-0.3,0-0.5-0.1c-0.2,0-0.3-0.1-0.5-0.1    c-0.1,0-0.2-0.1-0.3-0.1c-0.5-0.2-1-0.4-1.5-0.6c0,0,0,0,0,0C8.2,18,8,17.8,7.8,17.7c-0.1-0.1-0.2-0.1-0.3-0.2    c-0.1-0.1-0.2-0.2-0.3-0.2C7.2,17.2,7,17,6.9,16.9c-0.1-0.1-0.1-0.1-0.2-0.2l1.8-0.3c0.5-0.1,0.9-0.6,0.8-1.2    c-0.1-0.5-0.6-0.9-1.2-0.8L4.8,15c0,0,0,0,0,0L4,15.2c-0.3,0-0.5,0.2-0.6,0.4c-0.2,0.2-0.2,0.5-0.2,0.7l0.8,4.2    c0.1,0.5,0.5,0.8,1,0.8c0.1,0,0.1,0,0.2,0c0.5-0.1,0.9-0.6,0.8-1.2l-0.3-1.7c0,0,0,0,0,0c0.3,0.2,0.5,0.5,0.7,0.6c0,0,0,0,0.1,0    c0.1,0.1,0.2,0.1,0.3,0.2c0.2,0.2,0.5,0.3,0.7,0.5c0,0,0,0,0,0C7.7,20,8,20.1,8.3,20.3l0.1,0c0.1,0.1,0.3,0.1,0.5,0.2    c0.4,0.1,0.8,0.2,1.1,0.3c0.2,0,0.4,0.1,0.6,0.1c0,0,0.1,0,0.1,0c0.1,0,0.3,0,0.4,0c0.2,0,0.5,0,0.7,0c5,0,9-4,9-9    C20.9,11.4,20.4,11,19.9,11z"></path><path d="M4,13c0.6,0,1-0.4,1-1c0-3.9,3.1-7,7-7c0.2,0,0.5,0,0.7,0c0.2,0,0.3,0,0.5,0.1c0.2,0,0.3,0.1,0.5,0.1    c0.1,0,0.2,0.1,0.3,0.1c0.7,0.2,1.4,0.6,2,1c0.1,0.1,0.2,0.1,0.3,0.2c0.1,0.1,0.2,0.2,0.3,0.2C16.7,6.8,16.8,7,17,7.1    c0.1,0.1,0.1,0.1,0.2,0.2l-1.8,0.3c-0.5,0.1-0.9,0.6-0.8,1.2c0.1,0.5,0.5,0.8,1,0.8c0.1,0,0.1,0,0.2,0l4.2-0.8    c0.3,0,0.5-0.2,0.6-0.4s0.2-0.5,0.2-0.7L20,3.5c-0.1-0.5-0.6-0.9-1.2-0.8c-0.5,0.1-0.9,0.6-0.8,1.2l0.3,1.7c0,0,0,0,0,0    c-0.2-0.2-0.5-0.4-0.7-0.6c0,0,0,0-0.1,0c-0.1-0.1-0.2-0.1-0.3-0.2c-0.2-0.2-0.4-0.3-0.7-0.5c0,0,0,0-0.1,0    c-0.3-0.2-0.6-0.3-0.9-0.5l-0.1,0c-0.1-0.1-0.3-0.1-0.5-0.2c-0.4-0.1-0.8-0.2-1.1-0.3c-0.2,0-0.4-0.1-0.6-0.1c0,0-0.1,0-0.1,0    c-0.1,0-0.3,0-0.4,0c-0.2,0-0.5,0-0.7,0c-5,0-9,4-9,9C3,12.6,3.4,13,4,13z"></path><path d="M12,9c-1.7,0-3,1.3-3,3s1.3,3,3,3s3-1.3,3-3S13.7,9,12,9z M12,13c-0.6,0-1-0.4-1-1s0.4-1,1-1s1,0.4,1,1S12.6,13,12,13z"></path></g></g>
                            </svg>
                        </div>
                    </div>
                </div>
                <div id="allinwriter-move-button-wp"></div>
                <button id="allinwriter-btn" class="allinwriter-seo-articles-btn allinwriter-button">
                    <img src="<?php echo esc_url( plugins_url( 'img/icon48.png', __FILE__ ) ); ?>" alt="SEO Article"/>
                    SEO Article
                </button>
            </div>
        </div>
        <?php } );
    }
} );

/**
 * Add Visual Composer button.
 */
function allinwriter_add_vc_button() {
    if ( is_plugin_active( 'js_composer/js_composer.php' ) ) {
        ?>

        <div id="allinwriter-main-menu-seo-article-container">
            <div class="allinwriter-seo-article-container-full">
                <div class="allinwriter-speedometer-container">
                    <div class="allinwriter-speedometer">
                        <div id="allinwriter-indicator" class="allinwriter-speedometer-indicator" style="--allinwriter-score:0"></div>
                        <span id="allinwriter-score" class="allinwriter-score">N/A</span>
                        <div class="allinwriter-check-score">
                            <svg style="enable-background:new 0 0 24 24;width: 20px;" version="1.1" viewBox="0 0 24 24" xml:space="preserve" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink"><style type="text/css">
                                .st0{display:none;}
                                .st1{display:inline;}
                                .st2{opacity:0.2;fill:none;stroke:#000000;stroke-width:5.000000e-02;stroke-miterlimit:10;}
                                </style><g class="st0" id="grid_system"></g><g id="_icons" style="fill: #c7b5e9;"><g><path d="M19.9,11c-0.6,0-1,0.4-1,1c0,3.9-3.1,7-7,7c-0.2,0-0.5,0-0.7,0c-0.2,0-0.3,0-0.5-0.1c-0.2,0-0.3-0.1-0.5-0.1    c-0.1,0-0.2-0.1-0.3-0.1c-0.5-0.2-1-0.4-1.5-0.6c0,0,0,0,0,0C8.2,18,8,17.8,7.8,17.7c-0.1-0.1-0.2-0.1-0.3-0.2    c-0.1-0.1-0.2-0.2-0.3-0.2C7.2,17.2,7,17,6.9,16.9c-0.1-0.1-0.1-0.1-0.2-0.2l1.8-0.3c0.5-0.1,0.9-0.6,0.8-1.2    c-0.1-0.5-0.6-0.9-1.2-0.8L4.8,15c0,0,0,0,0,0L4,15.2c-0.3,0-0.5,0.2-0.6,0.4c-0.2,0.2-0.2,0.5-0.2,0.7l0.8,4.2    c0.1,0.5,0.5,0.8,1,0.8c0.1,0,0.1,0,0.2,0c0.5-0.1,0.9-0.6,0.8-1.2l-0.3-1.7c0,0,0,0,0,0c0.3,0.2,0.5,0.5,0.7,0.6c0,0,0,0,0.1,0    c0.1,0.1,0.2,0.1,0.3,0.2c0.2,0.2,0.5,0.3,0.7,0.5c0,0,0,0,0,0C7.7,20,8,20.1,8.3,20.3l0.1,0c0.1,0.1,0.3,0.1,0.5,0.2    c0.4,0.1,0.8,0.2,1.1,0.3c0.2,0,0.4,0.1,0.6,0.1c0,0,0.1,0,0.1,0c0.1,0,0.3,0,0.4,0c0.2,0,0.5,0,0.7,0c5,0,9-4,9-9    C20.9,11.4,20.4,11,19.9,11z"></path><path d="M4,13c0.6,0,1-0.4,1-1c0-3.9,3.1-7,7-7c0.2,0,0.5,0,0.7,0c0.2,0,0.3,0,0.5,0.1c0.2,0,0.3,0.1,0.5,0.1    c0.1,0,0.2,0.1,0.3,0.1c0.7,0.2,1.4,0.6,2,1c0.1,0.1,0.2,0.1,0.3,0.2c0.1,0.1,0.2,0.2,0.3,0.2C16.7,6.8,16.8,7,17,7.1    c0.1,0.1,0.1,0.1,0.2,0.2l-1.8,0.3c-0.5,0.1-0.9,0.6-0.8,1.2c0.1,0.5,0.5,0.8,1,0.8c0.1,0,0.1,0,0.2,0l4.2-0.8    c0.3,0,0.5-0.2,0.6-0.4s0.2-0.5,0.2-0.7L20,3.5c-0.1-0.5-0.6-0.9-1.2-0.8c-0.5,0.1-0.9,0.6-0.8,1.2l0.3,1.7c0,0,0,0,0,0    c-0.2-0.2-0.5-0.4-0.7-0.6c0,0,0,0-0.1,0c-0.1-0.1-0.2-0.1-0.3-0.2c-0.2-0.2-0.4-0.3-0.7-0.5c0,0,0,0-0.1,0    c-0.3-0.2-0.6-0.3-0.9-0.5l-0.1,0c-0.1-0.1-0.3-0.1-0.5-0.2c-0.4-0.1-0.8-0.2-1.1-0.3c-0.2,0-0.4-0.1-0.6-0.1c0,0-0.1,0-0.1,0    c-0.1,0-0.3,0-0.4,0c-0.2,0-0.5,0-0.7,0c-5,0-9,4-9,9C3,12.6,3.4,13,4,13z"></path><path d="M12,9c-1.7,0-3,1.3-3,3s1.3,3,3,3s3-1.3,3-3S13.7,9,12,9z M12,13c-0.6,0-1-0.4-1-1s0.4-1,1-1s1,0.4,1,1S12.6,13,12,13z"></path></g></g>
                            </svg>
                        </div>
                    </div>
                </div>
                <div id="allinwriter-move-button-wp"></div>
                <button id="allinwriter-btn" class="allinwriter-seo-articles-btn allinwriter-button">
                    <img src="<?php echo esc_url( plugins_url( 'img/icon48.png', __FILE__ ) ); ?>" alt="SEO Article"/>
                    SEO Article
                </button>
            </div>
        </div>
        <?php
    }
}
add_action( 'admin_footer', 'allinwriter_add_vc_button' );

/**
 * Generate an article via AJAX.
 */
function allinwriter_generate_article() {
    check_ajax_referer( 'allinwriter_nonce', 'security' );

    $keyword = isset( $_POST['keyword'] ) ? sanitize_text_field( wp_unslash( $_POST['keyword'] ) ) : '';
    $description = isset( $_POST['description'] ) ? sanitize_text_field( wp_unslash( $_POST['description'] ) ) : '';
    $rewrite_text = isset( $_POST['rewrite_text'] ) ? wp_kses_post( wp_unslash( $_POST['rewrite_text'] ) ) : '';
    $language = isset( $_POST['language'] ) ? sanitize_text_field( wp_unslash( $_POST['language'] ) ) : '';
    $country = isset( $_POST['country'] ) ? sanitize_text_field( wp_unslash( $_POST['country'] ) ) : '';
    $type = isset( $_POST['type'] ) ? sanitize_text_field( wp_unslash( $_POST['type'] ) ) : '';
    $post_id = isset( $_POST['post_id'] ) ? intval( $_POST['post_id'] ) : 0;
    $post_url = get_permalink( $post_id );
    $website_url = get_site_url();

    $api_key = get_option( 'allinwriter_api_key' );

    // Create a new post if post_id is 0
    if ( $post_id === 0 ) {
        $new_post_args = array(
            'post_title'   => wp_strip_all_tags( $keyword ),
            'post_content' => '',
            'post_status'  => 'draft',
            'post_author'  => get_current_user_id(),
            'post_type'    => 'post',
        );

        $post_id = wp_insert_post( $new_post_args );

        // Check for errors during post creation
        if ( is_wp_error( $post_id ) ) {
            wp_send_json_error( array( 'message' => __( 'An error occurred during post creation.', 'seo-articles-by-allinwriter'  ) ) );
            return;
        }
    }

    update_post_meta( $post_id, '_allinwriter_article_type', $type );

    $response = wp_remote_post( 'https://app.allinwriter.com/api/v1/documents/generate', array(
        'body' => array(
            'keyword' => $keyword,
            'description' => $description,
            'rewrite_text' => $rewrite_text,
            'language' => $language,
            'country' => $country,
            'internal_post_id' => $post_id,
            'article_url' => $post_url,
            'website_url' => $website_url,
            'type' => 'generateArticle' === $type ? 'free' : 'pro',
        ),
        'headers' => array(
            'Content-Type' => 'application/x-www-form-urlencoded',
            'Authorization' => 'Bearer ' . $api_key,
        ),
    ));

    $body = wp_remote_retrieve_body( $response );
    $data = json_decode( $body, true );

    if ( isset( $data['status'] ) && 'success' === $data['status'] ) {
        update_post_meta( $post_id, '_allinwriter_article_jd', $data['job_id'] );
        update_option( 'allinwriter_credits', $data['remained_credits'] );
        update_option( 'allinwriter_user_plan', $data['plan'] );  
        wp_send_json_success( array( 'job_id' => $data['job_id'] ) );
    } else {
        wp_send_json_error( array( 'message' => $data['message'] ?? __( 'An error occurred.', 'seo-articles-by-allinwriter'  ) ) );
    }
}
add_action( 'wp_ajax_allinwriter_generate_article', 'allinwriter_generate_article' );

/**
 * Check document status via AJAX.
 */
function allinwriter_check_status() {
    check_ajax_referer( 'allinwriter_nonce', 'security' );

    $job_id = isset( $_POST['job_id'] ) ? intval( $_POST['job_id'] ) : 0;
    $api_key = get_option( 'allinwriter_api_key' );

    $response = wp_remote_get( "https://app.allinwriter.com/api/v1/documents/check/{$job_id}", array(
        'headers' => array(
            'Authorization' => 'Bearer ' . $api_key,
        ),
    ));

    $body = wp_remote_retrieve_body( $response );
    $data = json_decode( $body, true );

    if ( ! empty( $data['result'] ) ) {
        wp_send_json_success( array(
            'content' => $data['result'],
            'seo_score' => $data['seo_score'],
            'post_id' => $data['internal_post_id'],
        ) );
    } else {
        wp_send_json_error( array( 'message' => __( 'Processing...', 'seo-articles-by-allinwriter'  ) ) );
    }
}
add_action( 'wp_ajax_allinwriter_check_status', 'allinwriter_check_status' );

/**
 * Check document score via AJAX.
 */
function allinwriter_check_score() {
    check_ajax_referer( 'allinwriter_nonce', 'security' );

    $post_id = isset( $_POST['post_id'] ) ? intval( $_POST['post_id'] ) : 0;
    $job_id = get_post_meta( $post_id, '_allinwriter_article_jd', true );
    $api_key = get_option( 'allinwriter_api_key' );
    $type = get_post_meta( $post_id, '_allinwriter_article_type', true );
    $content = isset( $_POST['content'] ) ? wp_kses_post( wp_unslash( $_POST['content'] ) ) : '';


    if(strlen($content) < 20) {
        $original_title = get_the_title( $post_id );
        $original_content = get_post_field( 'post_content', $post_id );
        $original_elementor_content = false;
    
        if ( did_action( 'elementor/loaded' ) ) {
            $original_elementor_content = \Elementor\Plugin::instance()->frontend->get_builder_content( $post_id, true );
            $original_content = strlen($original_elementor_content) > strlen($original_content) ? $original_elementor_content:$original_content;
        }
    
        $content = "<h1>" . $original_title . "</h1>" . $original_content; 
    }

    $response = wp_remote_post( 'https://app.allinwriter.com/api/v1/documents/checkscore', array(
        'body' => array(
            'content' => $content,
            'job_id' => $job_id,
            'type' => $type,
        ),
        'headers' => array(
            'Content-Type' => 'application/x-www-form-urlencoded',
            'Authorization' => 'Bearer ' . $api_key,
        ),
    ));

    $body = wp_remote_retrieve_body( $response );
    $data = json_decode( $body, true );

    if ( isset( $data['status'] ) && 'success' === $data['status'] ) {
        update_option( 'allinwriter_credits', $data['remained_credits'] );
        update_option( 'allinwriter_user_plan', $data['plan'] );  
        update_post_meta( $post_id, '_allinwriter_seo_score', $data['score'] );
        wp_send_json_success( array( 'seo_score' => $data['score'] ) );
    } else {
        wp_send_json_error( array( 'message' => $data['message'] ?? __( 'An error occurred.', 'seo-articles-by-allinwriter'  ) ) );
    }
}
add_action( 'wp_ajax_allinwriter_check_score', 'allinwriter_check_score' );

/**
 * Check sync account via AJAX.
 */
function allinwriter_sync_account() {
    check_ajax_referer( 'allinwriter_nonce', 'security' );
    
    $api_key = get_option( 'allinwriter_api_key' );

    $response = wp_remote_post( 'https://app.allinwriter.com/api/v1/documents/syncaccount', array(
        'body' => array(
            'type' => 'sync'
        ),
        'headers' => array(
            'Content-Type' => 'application/x-www-form-urlencoded',
            'Authorization' => 'Bearer ' . $api_key,
        ),
    ));

    $body = wp_remote_retrieve_body( $response );
    $data = json_decode( $body, true );

    if ( isset( $data['status'] ) && 'success' === $data['status'] ) {
        update_option( 'allinwriter_credits', $data['remained_credits'] );
        update_option( 'allinwriter_user_plan', $data['plan'] );  
        wp_send_json_success( array( 'credits' => $data['remained_credits'] ) );
    } else {
        wp_send_json_error( array( 'message' => $data['message'] ?? __( 'An error occurred.', 'seo-articles-by-allinwriter'  ) ) );
    }
}
add_action( 'wp_ajax_allinwriter_sync_account', 'allinwriter_sync_account' );



/**
 * Register REST API route for updating articles.
 */
function allinwriter_apply_register_rest_route() {
    register_rest_route( 'allinwriter/v1', '/update_article', array(
        'methods' => 'POST',
        'callback' => 'allinwriter_update_article',
        'permission_callback' => '__return_true',
    ));
}
add_action( 'rest_api_init', 'allinwriter_apply_register_rest_route' );

/**
 * Clean HTML content before updating.
 *
 * @param string $content HTML content to clean.
 * @return string Cleaned content.
 */
function clean_html_content( $content ) {
    // Remove unnecessary breaks and whitespaces.
    $content = preg_replace( '/<br\s*\/?>/i', '', $content );
    $content = str_replace( "&nbsp;", ' ', $content );
    $content = preg_replace( '/&nbsp;/', ' ', $content );
    $content = preg_replace( '/[\r\n]+/', "\n", $content );
    $content = preg_replace( '/(<br\s*\/?>\s*)+/', '<br>', $content );
    $content = preg_replace( '/(?:(?:\s*\n){2,})+/', "\n\n", $content );
    $content = preg_replace( '/>\s+</', '><', $content );
    $content = str_replace('  ', ' ', $content );

    return trim( $content );
}

/**
 * Update article content via REST API.
 *
 * @param WP_REST_Request $request The request object.
 * @return WP_REST_Response|WP_Error The response object or WP_Error on failure.
 */
function allinwriter_update_article( $request ) {
    $params = $request->get_json_params();
    
    $api_key = isset( $params['api_key'] ) ? sanitize_text_field( wp_unslash( $params['api_key'] ) ) : '';
    $post_id = isset( $params['post_id'] ) ? intval( $params['post_id'] ) : 0;
    $title  = isset( $params['title'] ) ? sanitize_text_field( wp_unslash( $params['title'] ) ) : '';
    $content = isset( $params['content'] ) ? $params['content'] : '';

    $content = clean_html_content( $content );
    $content = str_replace( array( "\r\n", "\r", "\n" ), "\n", $content );
    $content = preg_replace( '/\n{2,}/', "\n\n", $content );
    $content = wp_kses_post( $content );
    $score = isset( $params['score'] ) ? floatval( $params['score'] ) : 0;

    $stored_api_key = get_option( 'allinwriter_api_key' );
    if ( $api_key !== $stored_api_key ) {
        return new WP_Error( 'invalid_api_key', __( 'Invalid API key', 'seo-articles-by-allinwriter'  ), array( 'status' => 401 ) );
    }

    if ( ! $post_id || ! get_post( $post_id ) ) {
        return new WP_Error( 'invalid_post_id', __( 'Invalid post ID', 'seo-articles-by-allinwriter'  ), array( 'status' => 400 ) );
    }

    $original_title = get_the_title( $post_id );
    $original_content = get_post_field( 'post_content', $post_id );
    $original_elementor_content = false;

    if ( did_action( 'elementor/loaded' ) ) {
        $original_elementor_content = \Elementor\Plugin::instance()->frontend->get_builder_content( $post_id, true );
    }

    $update_data = array(
        'ID' => $post_id,
        'post_title' => $title,
        'post_content' => $content,
        'post_status'  => 'draft',
    );
    $updated_post_id = wp_update_post( $update_data, true );

    if ( is_wp_error( $updated_post_id ) ) {
        return new WP_Error( 'update_failed', __( 'Failed to update the post', 'seo-articles-by-allinwriter'  ), array( 'status' => 500 ) );
    }

    $elementor_data_raw = get_post_meta( $post_id, '_elementor_data', true );

    if ( $elementor_data_raw ) {
        $elementor_content = json_decode( $elementor_data_raw, true );

        $updated = false;
        foreach ( $elementor_content as &$element ) {
            if ( isset( $element['elType'] ) && 'widget' === $element['elType'] ) {
                if ( 'text-editor' == $element['widgetType'] || 'html' == $element['widgetType'] ) {
                    $element['settings']['editor'] = $content;
                    $element['settings']['html'] = $content;
                    $updated = true;
                    break;
                }
            }
        }

        if ( ! $updated ) {
            $elementor_content[] = array(
                'id' => uniqid(),
                'elType' => 'widget',
                'widgetType' => 'html',
                'settings' => array( 'html' => $content ),
                'elements' => array(),
                'isInner' => false,
            );
        }

        update_post_meta( $post_id, '_elementor_data', wp_json_encode( $elementor_content ) );
    }

    update_post_meta( $post_id, '_allinwriter_seo_score', $score );
    update_post_meta( $post_id, '_allinwriter_original_title', $original_title );
    update_post_meta( $post_id, '_allinwriter_original_content', $original_content );

    if($original_elementor_content) {
        update_post_meta( $post_id, '_allinwriter_original_elementor_content', $original_elementor_content );
    }

    update_post_meta( $post_id, '_allinwriter_title', $title );
    update_post_meta( $post_id, '_allinwriter_content', $content );

    return new WP_REST_Response( array( 'message' => __( 'Post updated successfully', 'seo-articles-by-allinwriter'  ) ), 200 );
}